#
# spec file for package gnokii
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnokii
Version:        0.6.31
Release:        13.6
Summary:        Nokia Connectivity Program
License:        GPL-2.0+
Group:          Hardware/Mobile
Url:            http://www.gnokii.org/
Source:         http://www.gnokii.org/download/gnokii/%{name}-%{version}.tar.bz2
Source1:        xgnokii.desktop
Source2:        gnokii.xpm
Source3:        README.SUSE
# PATCH-FIX-UPSTREAM gnokii-xgnokii.patch dimstar@opensuse.org -- Fix typo which results in xgnokii not being built and installed.
Patch0:         gnokii-xgnokii.patch
# PATCH-FIX-UPSTREAM gnokii-suid_flags.patch bnc#743142 vuntz@opensuse.org -- Respect SUID_CFLAGS/SUID_LDFLAGS; sent upstream by mail on 2012-02-24
Patch1:         gnokii-suid_flags.patch
# PATCH-FIX-OPENSUSE gnokii-date-time.patch crrodriguez@opensuse.org -- Do not include __DATE__ or __TIME__ in resulting binaries.
Patch2:         gnokii-date-time.patch
# PATCH-FIX-UPSTREAM invalid-cast.patch https://savannah.nongnu.org/patch/index.php?8685 schwab@suse.de -- Fix invalid cast
Patch3:         invalid-cast.patch
BuildRequires:  bluez-devel
BuildRequires:  coreutils
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1210
BuildRequires:  libX11-devel
BuildRequires:  libXpm-devel
%endif
BuildRequires:  libical-devel
# Needed for patch0 and patch1
BuildRequires:  libtool
BuildRequires:  libusb-devel
BuildRequires:  mysql-devel
BuildRequires:  pcsc-lite-devel
BuildRequires:  perl-XML-Parser
BuildRequires:  postgresql-devel
BuildRequires:  readline-devel
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
PreReq:         permissions
Requires:       bluez
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
gnokii is a package of programs for communicating with a Nokia cellular
phone in Linux. Read the READMEs in /usr/share/doc/packages/gnokii to
find out which models are supported.

%package -n xgnokii
Summary:        Nokia Connectivity Program
Group:          Hardware/Mobile
Requires:       gnokii
Requires:       gtk2
Provides:       gnokii:/usr/share/xgnokii

%description -n xgnokii
xgnokii is an X Window System front-end for gnokii. gnokii has to be
installed as well.

%package smsd
Summary:        Nokia Connectivity Program
Group:          Hardware/Mobile
Requires:       gnokii
Provides:       gnokii:/usr/share/smsd

%description smsd
gnokii is a package of programs for communicating with a Nokia cellular
phone in Linux. Please read the READMEs in
/usr/share/doc/packages/gnokii to find out which models are supported.

%package devel
Summary:        Nokia Connectivity Program
Group:          Hardware/Mobile
Requires:       %{name} = %{version}
Requires:       %{name}-smsd = %{version}

%description devel
gnokii is a package of programs for communicating with a Nokia cellular
phone in Linux. Please read the READMEs in
/usr/share/doc/packages/gnokii to find out which models are supported.

%lang_package
%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
# Needed by patch0 and patch1
autoreconf -fi
export CFLAGS="%{optflags} -fgnu89-inline -D_GNU_SOURCE -fPIC -Wall -Wno-unused -fstack-protector -fno-strict-aliasing"
export SUID_CFLAGS="-fPIE"
export SUID_LDFLAGS="-pie"
%configure \
    --enable-nls \
    --enable-security \
    --disable-static \
    --with-x
make %{?jobs:-j%jobs}
make -C smsd %{?jobs:-j%jobs}

%install
cp %{S:3} .
%makeinstall
make DESTDIR=%{buildroot} -C smsd install
rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/smsd/*.la
mkdir -p %{buildroot}%{_sysconfdir}
sed "s:/usr/local/sbin:%{_sbindir}:g" Docs/sample/gnokiirc > %{buildroot}%{_sysconfdir}/gnokiirc
chmod +x %{buildroot}%{_bindir}/sendsms
%find_lang %{name} %{?no_lang_C}
install -D -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/gnokii.xpm
%suse_update_desktop_file -i xgnokii Utility TelephonyTools Calendar ContactManagement Office GTK
# prepare documentation
find Docs -name 'Makefile.*' -exec rm -f {} \;
rm -rf Docs/man %{buildroot}%{_datadir}/doc/%{name}
chmod -x Docs/gnokii.nol
mv Docs/sample Docs/examples

%post
/sbin/ldconfig
%set_permissions %{_sbindir}/mgnokiidev

%verifyscript
%verify_permissions -e %{_sbindir}/mgnokiidev

%postun -p /sbin/ldconfig

%if 0%{?suse_version} > 1130

%post -n xgnokii
%desktop_database_post
%endif

%if 0%{?suse_version} > 1130

%postun -n xgnokii
%desktop_database_postun
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/gnokiirc
%doc COPYING COPYRIGHT ChangeLog MAINTAINERS TODO Docs/*
%doc %{_mandir}/man1/gnokii*
%doc %{_mandir}/man8/gnokiid*
%doc %{_mandir}/man8/mgnokiidev*
%{_bindir}/gnokii
%{_bindir}/gnokiid
%{_libdir}/*.so.*
%verify(not mode) %attr(0755, root, uucp) %{_sbindir}/mgnokiidev

%files -n xgnokii
%defattr(-,root,root)
%doc %{_mandir}/man1/xgnokii*
%{_bindir}/xgnokii
%{_datadir}/applications/*
%{_datadir}/pixmaps/*

%files smsd
%defattr(-,root,root)
%doc %{_mandir}/man1/sendsms*
%doc %{_mandir}/man8/smsd*
%{_bindir}/sendsms
%{_bindir}/smsd
%dir %{_libdir}/smsd
%{_libdir}/smsd/libsmsd_file.so
%{_libdir}/smsd/libsmsd_mysql.so
%{_libdir}/smsd/libsmsd_pq.so
%{_libdir}/smsd/libsmsd_sqlite.so

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_includedir}/gnokii.h
%{_includedir}/gnokii/

%files lang -f %{name}.lang

%changelog
* Thu Jun 11 2015 schwab@suse.de
- Force gnu89 inline semantics
- invalid-cast.patch: fix invalid cast
* Tue Sep 16 2014 crrodriguez@opensuse.org
- Fix devel package requires by letting the pkgconfig dependency
  generator act (Add pkg-config BuildRequires and remove all
  explicit Requires from the -devel package).
- Add gnokii-date-time.patch: Do not include __DATE__ or __TIME__
  in binaries.
* Wed Apr 11 2012 vuntz@opensuse.org
- Move the mysql/postgres smsd plugins from devel subpackage to
  smsd subpackage, where they really belong.
* Fri Feb 24 2012 vuntz@opensuse.org
- Add gnokii-suid_flags.patch: respect SUID_CFLAGS/SUID_LDFLAGS
  when building the suid binary mkgnokiidev.
- Set SUID_CFLAGS to -fPIE and SUID_LDFLAGS to -pie in %%build. This
  fixes bnc#743142.
- Add libX11-devel and libXpm-devel BuildRequires: they used to be
  implicitly brought in, but are needed after the xorg-x11
  packaging change. Only do this for 12.2 and later, though, to not
  break build on older systems.
* Sat Dec  3 2011 dimstar@opensuse.org
- Update to version 0.6.31:
  + libgnokii updates
  - add gn_lib_phone_change_driver() function to allow replacing
    used driver in runtime
  - GSM number type is rather mask than define; use it as such
    when parsing the input
  - avoid overruns in phonet
  - print names of config files it tried to open only if none
    could be used
  - fix setting alarms for zero length events read from icalendar
    files (eg. birthdays)
  - fix sms encoding: don't break multibyte characters when
    creating multipart messages
  - add possibility to disable setting serial port speed and
    DTR and RTS bits
  - change the order of lookup for the config file
    (http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=623694)
  - add id for Nokia 3109c and for Nokia C1-01 to misc.c only;
    both use model=series40
  - fix gn_sms_send() so the message could be resent  (Paweł Kot)
  - make the vcard reader handle also BDAY, TITLE, NICKNAME, ORG,
    X-SIP;POC and X-WV-ID
  - make the vcard reader handle also empty fields in N and in
    ADR (like in addresses without a PO Box)
  - support for compressed messages is not implemented yet
  - make the vcard writer handle also the date property in DC,
    MC, RC (the reader will ignore it) and ignore X-GNOKII-70 and
    X-GNOKII-71 (they are part of the N property)
  - make the vcard reader unfold correctly when lines end with CR
    LF
  - make the vcard writer fold lines at the 75th character
  - add id for Nokia 1280 to misc.c only; it doesn't support many
    commands because it's a Series 30; use model=series40
  - add id for Nokia 2700 clasic (series40)
  - add id for Nokia C2-03
  + nk6510 driver updates
  - fix calendar handling issues (few off-by-ones)
  - implement deletecalendarnote for series40 3rd+ Ed
  - handle TODOs and Notes in series40 3rd+ Ed
  - avoid segfault reported by Chuck when unexpected smsc
    information arrives
  - fix writing birthday entries to phonebook
  - fix setting speed dials with location > 255
  + gnokii updates
  - create path to gnokii-errors even on Windows
  - allow to specify custom path for gnokii-errors
  - make the output of --getspeeddial more readable (show SM or
    ME instead of a number) and consistent with the arguments of
  - -setspeeddial
  + fake driver updates
  - add multipart message to SMS inbox
  - add ability to use --writephonebook
  + smsd updates
  - do not call GetSMSC every time SMS is sent
  - NULL freed pointers
  + xgnokii updates
  - set icon "phone" for all windows when using gtk+ 2.6 or later
  + at driver updates
  - correctly initialize memory type on WritePhonebookExt
  - Samsung SGH-U600 suppots extended phonebook
  - AT+SBPW=0,... is not supported for SM memory
  - Samsung B2100 encodes phone numbers
  - Return GN_ERR_EMPTYLOCATION also for phones that return error
- Add gnokii-xgnokii.patch: Fix typo which stops xgnokii from being
  built and installed.
- Add libtool BuildRequires and call autoreconf, as the above patch
  touches configure.in and we need to rebootstrap.
- Remove _service.
- Change license tag to spdx identifier.
* Thu May  5 2011 vuntz@opensuse.org
- Use %%set_permissions instead of deprecated %%run_permissions in
  %%post.
- Add readline-devel and sqlite3-devel BuildRequires for additional
  features.
* Sun Mar 13 2011 jslaby@suse.de
- Update to version 0.6.30:
  + support for phonet
  + fix SMS parsing
  + add ids for some more models
  + fix calendar crash
  + fix --reset hard handling
- Drop gnokii-new-libpcsc-lite.patch: fixed upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Split lang subpackage.
* Mon Jan 17 2011 vuntz@opensuse.org
- Add gnokii-new-libpcsc-lite.patch, that we apply on 11.4 and
  later: fix build with libpcsc-lite >= 1.6.0. Taken from git.
* Wed Apr 28 2010 dimstar@opensuse.org
- Update to version 0.6.29:
  + Gnokii updates:
  - make SMS and MMS commands suggest using --showsmsfolderstatus
    to know which memory types are supported
  - fix command with multiple arguments handling in --shell
  - show reference number also for sendlogo() and sendringtone()
  - fix random segfault when using --deletecalendarnote
  + Libgnokii updates:
  - add more debug information to encoding functions
  - add ids for Nokia 2760, Nokia 5130 XpressMusic, Nokia 5310
    XpressMusic, Nokia 6700 classic and Nokia 6085 to misc.c (use
    model=series40 for all)
  - add TA and CB memory types to gn_str2memory_type() and to
    gn_memory_type2str(); they were only in
    gn_memory_type_print()
  - use more standard config file locations:
    %%APPDATA%%\gnokii for Windows
    $HOME/Library/Preferences/gnokii for MacOS X
    $XDG_CONFIG_HOME/gnokii for others (following
    freedesktop.org)
  - fallback to use mbrtowc()/wcrtomb() or mbtowc()/wctomb() if
    iconv_open() fails
  - fix sending multipart 8-bit SMS
  - fix SMS encoding
  - fix SMS splitting into parts (concatenated messages with
    UCS-2 encoding)
  - add dependency on glib
  - make --writephonebook work on Series40 3rd Ed+
  - when reading phonebook dump unknown blocks in debug mode
  + Many driver updates
  + Updated translations.
- Drop gnokii-vcal_c-bufferoverflow.patch: fixed upstream.
* Wed Feb 24 2010 dimstar@opensuse.org
- Update to version 0.6.28:
  * build system updates
    o fix Mac OS X build    (Paweł Kot, Daniele Forsi, Jeff Rafter)
    o fix NetBSD build and enable Bluetooth support (Daniele Forsi)
    o use = instead of == in configure to be compliant with sh
    syntax                                          (Guido Falsi)
    o add options to disable mysql/postgres smsd plugins
    compilation                                     (Alin Năstac)
    o use strdup instead of strndup - fixes FreeBSD < 8 compilation
    (Guido Falsi)
    o remove deprecated kernel modules for DKU2 cable; supported
    DKU2 driver uses libusb (connection = dku2libusb)
    (Daniele Forsi, Paweł Kot)
    o remove patches/freebsd-ltmain_sh.patch since it is no more
    needed                           (Daniele Forsi, Guido Falsi)
    o fix setenv()/unsetenv() build on Solaris          (Paweł Kot)
    o fix getopt_long() build on Solaris                (Paweł Kot)
  * libgnokii changes
    o print more verbose messages on device locking problems
    (Paweł Kot)
    o add GN_ERR_LOCKED error code                      (Paweł Kot)
    o strip trailing '\r's when parsing vcard files     (Paweł Kot)
    o enable Bluetooth support for FreeBSD            (Guido Falsi)
    o fix segfault on sending long sms                  (Paweł Kot)
    o fix off by one bug in atbus_rx_statemachine() found with
    valgrind                           (Daniele Forsi, Paweł Kot)
    o fix retval of char_ucs2_encode()   (Daniele Forsi, Paweł Kot)
    o autodetect bluetooth channel for gnapplet         (Paweł Kot)
    o don't use default rfcomm channel since we have autodetection
    (Paweł Kot)
    o add id for Nokia 1209 to misc.c only; use model=series40 but
    you will get limited functionality because this phone is a
    Series 30                                            (ncrfgs)
    o add a gn_lib_init() function to translate libgnokii messages
    also when the library is used by programs other than gnokii,
    xgnokii and smsd; only programs that DON'T connect to a phone
    need to call it explicitely                   (Daniele Forsi)
    o set To headers instead of From headers when saving to mbox
    outbox messages                                    (analyzer)
    o add gn_mms_get() and gn_mms_delete() functions (decoding to
    text and MIME formats is incomplete and subject to change)
    (Daniele Forsi)
    o assign random reference ids to sent SMS (was always 0)
    (Paweł Kot)
    o fix splitting unicode multipart messages          (Paweł Kot)
    o with multipart message always send the smallest part as the
    last one                                          (Paweł Kot)
    o represent more statuses with enum gn_power_source
    (Daniele Forsi)
    o correctly decode non-ascii characters in default alphabet
    messages                                          (Paweł Kot)
    o when sending multipart sms return reference numbers for all
    the parts                                         (Paweł Kot)
    o add GN_SMS_Unknown to gn_sms_message_status   (Daniele Forsi)
    o fix decoding SMS-STATUS-REPORT     (Daniele Forsi, Paweł Kot)
    o set GN_SMS_USER_DATA_MAX_LENGTH to 256            (Paweł Kot)
    o replace GNOKII_API bool with GNOKII_API int for the function
    definition                                        (Paweł Kot)
    o introduce better bool definition             (Fabian Groffen)
    o correctly encode GN_GSM_NUMBER_Alphanumeric   (Daniele Forsi)
    o use UCS-2 internal representation when sending SMS; it will
    allow better recognition for non-ascii but default alphabet
    characters                                        (Paweł Kot)
    o fix off-by-one bug in base64_encode               (Paweł Kot)
  * gnokii updates
    o strip the trailing newline when --entersecuritycode did not
    read from a terminal                          (Daniele Forsi)
    o add --getmms and --deletemms commands         (Daniele Forsi)
    o deprecate -l option --sendsms; gnokii will now detect itself
    long sms                                          (Paweł Kot)
    o more efficient way to get all smses               (Paweł Kot)
    o add SEC option to --entersecuritycode to input security code
    (supported by nk6510 and nk6100 drivers)     (Ladislav Michl)
    o make --sendsms refuse alfanumeric destination "numbers" to
    catch typos and make --savesms accept them because it's
    useful for testing                            (Daniele Forsi)
    o allow sending an empty SMS                        (Paweł Kot)
  * at driver updates
    o initialize reg_notification and reg_callback_date (Paweł Kot)
    o fix --getnetworkinfo on some phones (Siemens S55) with
    unregistered SIM                                  (Paweł Kot)
    o accept also +CCLK and +CREG responses without double quotes
    (Daniele Forsi)
    o fix --getphonebook segfault (bug #25378)          (Paweł Kot)
    o make Huawei phones notify SMS arrival (they seem to send
    notifications only to the second port, eg /dev/ttyUSB1)
    fixes http://savannah.nongnu.org/bugs/?25115  (Daniele Forsi)
    o cache GetBattery as it is extensivly used by --monitor and
    doesn't change too frequently                     (Paweł Kot)
    o make GetBattery understand also 2 (no battery) and 3 (power
    fault)                                        (Daniele Forsi)
    o if AT+GMM fails, try AT+CGMM (Huawei E220 doesn't support
    +GMM but supports +CGMM); fixes #26039            (Paweł Kot)
    o accept also +CREG responses with an odd number of digits in
    the Cell ID field                             (Daniele Forsi)
    o when setting a new memory name use the current encoding
    instead of forcing "GSM" encoding             (Daniele Forsi)
  * nk6510 driver updates
    o fix segfault on deletesms with S40_30             (Paweł Kot)
    o sanity checks for number of messages in folder; increase max
    sms number in folder to 1024                      (Paweł Kot)
    o implement GN_OP_GetMMS and GN_OP_DeleteMMS    (Daniele Forsi)
    o don't fallback to S40_30 mode on every error      (Paweł Kot)
    o SMS status is sometimes not returned - check for reply length
    (Paweł Kot)
    o improve detection of SMS and MMS with S40_30 and correctly
    decode UCS2 SMS and read/unread/sent/unset status; also fix
    reading SMS from non-IN folders               (Daniele Forsi)
    o enable input of security code (this driver now supports PIN
    and SEC and throws an error for other codes)  (Daniele Forsi)
    o distinguish between "file not found" for --getfile (return an
    error) and "empty directory" for --getfilelist (do not return
    an error)                                     (Daniele Forsi)
    o when an empty file folder is cached always use a timeout > 0
    since 0 means "no timeout" and the list is never refreshed;
    this also affects reading SMS from S40_30     (Daniele Forsi)
  * gnapplet driver updates
    o fix string type argument length passed to the phone
    (Paweł Kot)
  * documentation updates
    o in sample gnokiirc mention that the rfcomm_channel parameter
    is ignored when using the FBUS protocol       (Daniele Forsi)
    o in gnokii man page add details to --writephonebook and
    remove reference to non existant -i parameter (Daniele Forsi)
    o add comments to all functions in common/gsm-encoding.c
    (Daniele Forsi)
    o in sample gnokiirc mention that on Win32 a COM port with a
    number greater than 9 is named like \\.\COM10 (Daniele Forsi)
    o in sample gnokiirc for Win32 mention that
    port = aa:bb:cc:dd:ee:ff is valid too         (Daniele Forsi)
  * smsd updates
    o fix segfault when using the nk6100 driver     (Daniele Forsi)
    o add examples directory with action files      (Daniele Forsi)
    o print short version on every startup; it should bring better
    bugreports                                        (Paweł Kot)
    o reading SMS from S40_30 would stop working when inbox becomes
    empty (fixed in the driver)                   (Daniele Forsi)
    o enable sending long sms with postgresql module    (Paweł Kot)
    o rollback autodection of first sms position. First position
    now defaults to 1 and can be changed to 0 with -0,
  - -firstpos0 command line argument              (Jan Derfinak)
  * xgnokii updates
    o use Icon=phone instead of Icon=cellphone            (Ariszló)
  * fake driver updates
    o implement GetSMS for testing                      (Paweł Kot)
    o generate reference id for SendSMS                 (Paweł Kot)
    o add SMS-STATUS-REPORT sample SMS for GetSMS testing
    (Paweł Kot)
    o add more testcases for GetSMS                     (Paweł Kot)
  * translation updates
    o updated French translation                             (Ploc)
    o updated Italian translation                   (Daniele Forsi)
  * utils updates
    o add gnokii-configure utility (not installed by make install
    because it depends on Python and libglade)    (Daniele Forsi)
  * nk7110 driver updates
    o fix segfault on getsms and deletesms when raw_sms->number < 1
    (Daniele Forsi)
  * pcsc driver updates
    o deprecate model=pcsc and connection=pcsc values; use
    model=APDU and connection=libpcsclite instead (Daniele Forsi)
  + Add gnokii-vcal_c-bufferoverflow.patch, from upstream git.
* Tue Mar 17 2009 prusnak@suse.cz
- updated to 0.6.27
  * build system updates
    o move config.rpath from config/ to toplevel        (Paweł Kot)
    o remove all m4 macros except ac_expand_dir.m4 and
    acx_pthread.m4                                    (Paweł Kot)
    o use -N instead of -r in addition to -O option to make new
    wget happy                                        (Paweł Kot)
    o be compatible with systems where iconv() is not in glibc
    (Daniele Forsi)
    o make Mac OS X use glibtoolize instead of libtoolize in
    ./autogen.sh                                  (Daniele Forsi)
  * win32 updates
    o make it build again                             (Jari Turkia)
  * nk6510 driver updates
    o advance progress indicator for file download in place
    (Yoni Rabkin)
    o detect empty/invalid SMS locations                (Paweł Kot)
    o support two bytes for raw location numbers also for reading
    and deleting SMS (it was already supported for saving) this
    partially fixes reading SMS with Nokia Series 40 3rd Edition
    phones and other newer and older phones       (Daniele Forsi)
    o replace SMS reading implementation for Series40 3rd Edition
    and later phones                                  (Paweł Kot)
    o support new memory types for SMS on series40: DR (Drafts) and
    OUS (Outbox, items to be sent)                    (Paweł Kot)
  * libgnokii updates
    o re-add iconv detection, fixes problem with non-ASCII messages
    and data, spotted by Daniele Forsi           (Bastien Nocera)
    o add callback function for advance progress indicator
    (Paweł Kot)
    o translate country names if iso-codes package is installed;
    see INSTALL for details                       (Daniele Forsi)
    o edit MCC list to be closer to
    http://en.wikipedia.org/wiki/Mobile_network_code and edit
    country list to be closer to iso-codes        (Daniele Forsi)
    o Add the new gn_phonebook2vcardstr() and
    gn_vcardstr2phonebook() functions, to manipulate strings
    rather than filedescriptors when parsing phonebook entries
    (Bastien Nocera)
    o Add similar gn_calnote2icalstr(), gn_icalstr2calnote(),
    gn_todo2icalstr(), and gn_icalstr2todo() functions
    to manipulate calendar entries               (Bastien Nocera)
    o steal rfcomm channel autodetection code from
    gnome-phone-manager                               (Paweł Kot)
    o make gn_sms_send() propagate the reference number from its
    local data->raw_sms to caller's data->sms     (Daniele Forsi)
    o add unconditional divert type (reason)            (Paweł Kot)
    o fix potential stack corruption with long phone names; fixes
    [#23941] (https://savannah.nongnu.org/bugs/?23941)  (Paweł Kot)
    o add ids for Nokia N73 (model=at), Nokia 7373 and Nokia 3500
    Classic (model=series40) to misc.c only       (Daniele Forsi)
    o print out an overrun frame when detected          (Paweł Kot)
    o gn_file_list struct supports an arbitrary number of files in
    the directory                                     (Paweł Kot)
    o add new memory types for SMS: SR (Status Reports), DR
    (Drafts) and OUS (Outbox, items to be sent)       (Paweł Kot)
    o increase max number of SMS folders supported from 24 to 64
    (many phones handled by the nk6510 driver support 20 folders
    created by the user and more than 4 folders created by the
    phone)                                            (Paweł Kot)
  * documentation updates
    o updated Polish translation                        (Paweł Kot)
    o updated Italian translation                   (Daniele Forsi)
    o update Nokia DKU2 rules sample file for udev  (Daniele Forsi,
    Paweł Kot)
    o update gnokii man page with --answercall --hangup --divert
  - -keysequence --enterchar --listnetworks --getnetworkinfo
    and --showsmsfolderstatus that were missing and add details
    to --dialvoice and --setspeeddial             (Daniele Forsi)
  * gnokii updates
    o make --getsms accept at most 6 arguments, not 5 so that
    gnokii --getsms SM 1 2 -d -f myfile actually works; exit
    immediately (and do not delete SMS if --delete was specified)
    when user answers "no" to overwrite prompt    (Daniele Forsi)
    o make --sendsms, --savesms, --getsms and --deletesmsfolder
    return with more specific error codes GN_ERR_WRONGDATAFORMAT,
    GN_ERR_INVALIDMEMORYTYPE and GN_ERR_INVALIDLOCATION where
    appropriate, instead of -1 or GN_ERR_FAILED   (Daniele Forsi)
    o add country name to --listnetworks output     (Daniele Forsi)
    o error message for too long text provided to --sendsms --long
    would sometimes print wrong max size          (Daniele Forsi)
    o Use the new gn_phonebook2vcardstr() function (Bastien Nocera)
    o fix handling of arguments in --savesms: make it actually
    accept -l|--location and at most 12 parameters, not 10
    (Daniele Forsi)
    o make --sendsms print the reference number of sent SMS
    (Daniele Forsi)
    o align --showsmsfolderstatus output -- folder abbreviation can
    have up to 3 chars                                (Paweł Kot)
    o implement --shell option that will allow run more than one
    gnokii command inside one session                 (Paweł Kot)
    o sms folder abbreviation may be 3-char             (Paweł Kot)
    o extend max SMS folder name length                 (Paweł Kot)
  * at driver updates
    o workaround for Sagem myW-8 (in atsag.c) and other phones (in
    atgen.c) returning the wrong answer to GN_OP_GetModel
    (Daniele Forsi)
    o fix segfault on empty addressbook entry last name on Samsung
    (Paweł Kot)
    o fix detecting current charset with AT+CSCS?   (Daniele Forsi)
    o fix encoding issues (again)                       (Paweł Kot)
    o fix GetMemoryStatus timing out on some Sony Ericsson phones
    (Bastien Nocera)
    o fix changing folders in some cases on Sony Ericsson phones
    (Bastien Nocera)
    o fix GetMemoryStatus being wrong when some phonebook entries
    contained non-ASCII characters               (Bastien Nocera)
    o decode date/time for --getphonebook DC MC RC on phones that
    also encode number, eg Sony Ericsson          (Daniele Forsi)
    o fix divert call commands invocation               (Paweł Kot)
    o be more verbose when the phone doesn't support PDU SMS mode
    (Carles Pina i Estany)
    o fix phonebook reading for phones that add spaces after commas
    in +CPBR: response                            (Daniele Forsi)
    o fix folder list parsing for wavecom modems   (BORBELY Zoltan)
    o make phonebook work on all Samsung phones; make extended
    phonebook configurable; FIXME: detect which phones support
    extended phonebook                                (Paweł Kot)
    o support SMS memory names longer than 2 chars  (Daniele Forsi)
    o Sagem was reported to encode numbers (bug #24116) (Paweł Kot)
    o let it use also connection = tcp to use an Ethernet to serial
    adapter or a phone connected to a remote PC   (Daniele Forsi)
    o Samsung SHG-L760 was reported to respond to some commands
    without echoing the original request              (Paweł Kot)
  * xgnokii updates
    o display longer model names in Options dialog  (Daniele Forsi)
  * smsd updates
    o fix potential segfault with file module on empty input SMS
    (Jan Derfinak)
    o allow to send multiline SMS with file module   (Jan Derfinak,
    Joan)
    o don't use variable after it is freed              (Paweł Kot)
    o default module is file module                     (Paweł Kot)
  * link layer updates
    o usb_open() on DKU2 device just once -- otherwise it doesn't
    work on FreeBSD                                   (Paweł Kot)
* Tue Oct  7 2008 prusnak@suse.cz
- fixed incorrect encoding for the synchronized entries
* Tue Sep 16 2008 dmueller@suse.de
- bluez-libs is dropped
* Mon Sep 15 2008 dmueller@suse.de
- adjust buildrequires
* Fri Jul 25 2008 prusnak@suse.cz
- updated to 0.6.26
  * translation updates
    o search translations in $(localedir) and use exactly the same
    code in gnokii, xgnokii, smsd and gnokiid     (Daniele Forsi)
  * at driver updates
    o use AT+GMM to get the model name as it gives a more readable
    output for Sony Ericssons and makes no difference for other
    tested phones                      (Paweł Kot, Daniele Forsi)
    o support 4-bytes cell id                           (Paweł Kot)
    o cache pdu mode not to issue the command with every sms
    (Paweł Kot)
    o cache output of AT+XXXX=? commands which can be reused
    (Paweł Kot)
    o handle extended registration status in a sane way (Paweł Kot)
    o better handle encoding issues wrt numbers and memory types;
    some phones want them to be encoded using encoding being set
    (like Sony Ericsson) some want them as ascii (like Nokia)
    (Paweł Kot)
    o optimize number of commands sent to the phone for multiple
    operations like reading entire phonebook or entire inbox
    (Paweł Kot)
    o better handle empty +COPS responses               (Paweł Kot)
    o handle +CREG notifications (registration status)  (Paweł Kot)
    o correctly parse output for +CREG with LAC bytes swapped
    (Paweł Kot)
    o add separate files for LG and Sagem phones        (Paweł Kot)
    o for GN_OP_GetSMSCenter always provide a default name and set
    default_name field because AT protocol never provides a name
    (Daniele Forsi)
  * gnokii updates
    o support 4-bytes cell id                           (Paweł Kot)
  * libgnokii updates
    o do line unfolding/folding when reading/writing vCards and
    limit subentry size to 61 bytes (fixes in part
    https://savannah.nongnu.org/bugs/index.php?23086)
    (Daniele Forsi)
    o handle no '\n' at the end of the config file      (Paweł Kot)
    o don't allocate memory for comments for in-memory config
    representation                                    (Paweł Kot)
    o comments in the config files may be started at any position
    in the line                                       (Paweł Kot)
    o add missing quotes to #define LIBGNOKII_VERSION_STRING
    (Daniele Forsi)
  * smsd updates
    o avoid "duplicated message" error with concatenated messages
    on MySQL                                          (Paweł Kot)
    o more verbose debug information                    (Paweł Kot)
  * pcsc driver updates
    o implement GN_OP_GetSMSCenter for --getsmsc    (Daniele Forsi)
  * nk6510 driver updates
    o for GN_OP_GetSMSCenter provide a default name if a name isn't
    received; fix setting default_name field; when phone numbers
    are empty do not copy the string "(none)"     (Daniele Forsi)
  * nk7110 driver updates
    o for GN_OP_GetSMSCenter provide a default name if a name isn't
    received; fix setting default_name field; when phone numbers
    are empty do not copy the string "(none)"     (Daniele Forsi)
* Fri Jul 25 2008 prusnak@suse.cz
- updated to 0.6.25
  * at driver updates
    o correctly handle different length memory names (like F10) so
    that phone can respond with ERROR             (Daniele Forsi)
    o fix call notification for phones that reply with "+CRING: "
    instead of "+CRING: VOICE"                    (Daniele Forsi)
    o now it can decode status report SMS           (Daniele Forsi)
  * pcsc driver updates
    o make it compatible also with libpcsclite 1.3.1+
    (Pavel Kankovsky)
    o implement the functions to support --deletesms and
  - -deletephonebook; deleted items are completely overwritten
    with 0xff                                   (Pavel Kankovsky)
    o implement the functions to support --getsecuritycodestatus
    and --entersecuritycode PIN                 (Pavel Kankovsky)
    o now it can decode status report SMS           (Daniele Forsi)
  * libgnokii changes
    o make char_bcd_number_get() decode non numeric codes "*#pbc"
    (Daniele Forsi)
    o tm_mon in tm struct starts from 0         (Wiesław Ochmiński)
    o make vCard output of gn_phonebook2vcard() compliant with
    RFC2426 using underscores instead of hyphens (vCards created
    by previous versions are still read) and always generating
    the "N:" property; (fixes a part of
    https://savannah.nongnu.org/bugs/?22611)      (Daniele Forsi)
    o split phonebook entry information (previously in
    X_GSM_STORE_AT) into X-GSM-MEMORY and X-GSM-LOCATION like in
    gnokii mbox file output and use "None" instead of "Unknown"
    for GN_PHONEBOOK_GROUP_None                   (Daniele Forsi)
    o make gn_vcard2phonebook() parse and store the "N:" property
    (closes https://savannah.nongnu.org/bugs/?22611)
    (Daniele Forsi)
    o move declaration of gn_get_connectiontype() from
    gnokii-internal.h to gnokii.h because it is a public function
    (Daniele Forsi)
    o merge from devel branch the functions to convert enum values
    into localized strings             (Paweł Kot, Daniele Forsi)
    o use the new function to convert enum values into localized
    strings to output vCard category              (Daniele Forsi)
    o rewrite gn_sms_pdu2raw() to decode also status reports
    (this is used by atgen.c and pcsc.c)          (Daniele Forsi)
  * gnokii changes
    o allow to use --entersecuritycode with another gnokii command
    (Pavel Kankovsky)
    o all specialized functions return gn_error         (Paweł Kot)
    o use the new functions to convert enum values into localized
    strings (merge code from devel branch with minor changes)
    (Daniele Forsi)
  * nk6100 driver updates
    o Nokia 3210, 3310 and 3330 do not support caller groups (tested
    for NSE-8, NHM-5 and NHM-6, guessed for NSE-9 and NHM-5NX)
    so return GN_PHONEBOOK_GROUP_None on reading   (Daniele Forsi)
* Tue Mar 25 2008 prusnak@suse.cz
- updated to 0.6.24
  * libgnokii changes
    o prepare new API for config handling; it will allow third
    party applications to use own configuration
    o add id for Nokia 5300 to misc.c only; use model=series40 in
    gnokiirc for this and similar phones
    o create a new function moving code from atgen.c to split raw
    fields of a PDU coded SMS and copy them to gn_sms_raw struct
    for later decoding
    o change gn_memory_type2str() to be the inverse of
    gn_str2memory_type(), ie converting a numeric gn_memory_type
    like GN_MT_ME into a short string like "ME"; converting into
    a more user friendly string like "Internal memory" is now
    done by gn_memory_type_print()
  * at driver updates
    o in ReplyGetSMS() use the new function to split raw fields of
    a PDU coded SMS (code refactoring, no functional changes)
    o do not segfault when AT+COPS? returns only the first value
    as in +COPS: 0
    o AT protocol supports only one SMS Center, so pretend that its
    location is number 1 and return GN_ERR_INVALIDLOCATION
    when requested SMSC location is not 1
    o use gn_str2memory_type() and the new gn_memory_type2str() to
    convert memory arguments
    o implement the functions to support --showsmsfolderstatus for
    up to 4 folders
    o fix setting the current memory on Sony Ericsson phones
    o force the encoding to be GSM when we're expecting an "ASCII"
    answer, fixes a lot of functionality on Sony Ericsson, Samsung
    and Sagem phones.
    o in GN_OP_SaveSMS set data->raw_sms->number with location
    number where message was stored, as expected by gnokii
  - -savesms
    o in Sony Ericsson driver atsoer.c fix off by one command
    string length in se_at_memory_type_set()
    o parse date and time if sent by phone when reading phonebook
    entries (eg DC, MC, RC memories)
  * pcsc driver updates
    o implement --getsms from SM memory; this can read deleted SMS
    o implement the functions to support --showsmsfolderstatus
  * documentation updates
    o add to gnokii man page the missing options of --sendsms
    command (--8bit, --concat, --animation and --wappush) and
    document all its other long options
    o try to make an impression that all the phones are supported
  * gnokii updates
    o make --getsmsc understand the "end" keyword
    o the -f and -F options of --getsms now output short memory
    names for X-GSM-Memory
    o use the new gn_memory_type2str() to show memory name instead
    of numeric ID in --showsmsfolderstatus output
  * nk6100 driver
    o use "SIM card" instead of "SMS Inbox" as SM folder name for
  - -showsmsfolderstatus
* Tue Feb 19 2008 prusnak@suse.cz
- updated to 0.6.23
  * documentation updates
    o add further details for logo commands to gnokii man page
    and fix --getwapsetting/--writewapsetting
    o update xgnokii/ChangeLog
  * build system updates
    o don't include packaging directory in the release tarballs
    o don't allow to build without debug
    o switch build system to automake
    o allow silent (make -s) build
    o add missing includes on glibc 2.7
    o get rid of XGNOKIIDIR
    o add --disable-smsd option to disable smsd compilation and
    installation
  * libgnokii updates
    o update gsm network list
    o use defines instead of hardcoding values
    o correct FBUS sequence number initialization
    o make the function gn_get_connectiontype() visible even when
    compiling with -fvisibility=hidden
    o remove deprecated gn_cfg_read() function
    o initialize active call table with Idle state for checking
    active calls
  * xgnokii updates
    o avoid to use hardcodes
    o avoid segfault on calendar fetching
    o display a dialog to inform the user that some functions in
    the Calendar window are not yet implemented ("Save to phone",
    "Send via SMS", "Import from file", "Export to file"); also
    make menu items for "Add reminder", "Add call", "Add
    meeting", "Add birthday", "Delete note" work
  * pcsc driver updates
    o provide more information to the --identify command
    o implement --getnetworkinfo
  * gnokii updates
    o trailing \n with --sendsms was not calculated into sms length
    but it was added into sms text; as the result if \n was 161st
    char in the sms and it was the last one we were telling user
    that just one sms will be sent and we sent two
  * nk6510 driver updates
    o print out rf level information in debug mode even it gnokii
    structures are not initialized
    o add call notification handler
    o attempt to "fix" problem with getting folder list on some
    Series40 phones
* Wed Nov 28 2007 prusnak@suse.cz
- updated to 0.6.22
  * build system updates
    o make install and install-devel work correctly
    o xgnokii.pc should be installed with install-devel
    o add MS Visual C++ 2008 project files
  * at driver updates
    o make CNMI mode argument configurable in at_driver_instance
    o don't fallback to default memory type if desired one is not
    available
    o new specific driver for Motorola
  * xgnokii updates
    o change the way phonebooks entries are deleted
    o make sure it didn't copy subentries from previously read
    phonebook entry
    o fix moving phonebook entries from SIM to phone and vice versa
    o when a phonebook entry is successfully saved or deleted do
    not process it again
    o do not let the user write phonebook names longer than the
    space allocated by libgnokii
  * link layer updates
    o reset link layer status when resending message
    o extend buffer for the reply as a workaround for libusb
    problem
    o improve DKU-5 initialization again
  * libgnokii updates
    o export delivery report status as enum, not only text
    o use businessCategory for caller group number when exporting
    and importing phonebook entries in LDIF format (instead of
    businessGroup and callerGroup)
    o add function to return connection name
    o make gn_gsm_initialise() print the "phone instance config" in
    a format that can be copied into gnokiirc
  * nk6510 driver updates
    o don't free driver instance too early
* Mon Nov 12 2007 prusnak@suse.cz
- updated to 0.6.21
  * xgnokii updates
    o update xgnokii desktop file
    o reading contacts from phone would miss the last entries if
    phonebook contained holes (see gnokii fix for --getphonebook
    below)
    o importing contacts from file now replaces entries with the
    same location number leaving the others untouched (in prior
    versions the others were deleted)
    o replace sprintfs() with snprintfs()
  * link layer updates
    o improve DKU-5 initialization stage
    o be careful with return value from read()
  * at driver updates
    o return an error from at_memory_type_set() when a phonebook
    memory type supported by libgnokii isn't supported by the
    phone's AT+CPBS= command
    o avoid memory corruption due to too small buffer with getsms
    and delete sms after incoming sms notification
  * build system updates
    o change location of gnapplet.sis
    o configure.in and makefiles simplification
    o install gnokii.pc with install-devel and not install target
  * libgnokii updates
    o new error code GN_ERR_ASYNC
    o add support for async way of send_sms()
    o add ids for Nokia 6030
    o add ids for Nokia 3110 classic
    o replace sprintfs() and strcpys() with snprintfs
    o return an error when trying to read from file more phonebook
    subentries than the space allocated
  * gnapplet driver updates
    o add support for setactiveprofile
  * gnokii updates
    o fix --getphonebook not reading the last entries in two cases
    when some entries before those meant to be read were empty
    and make it fail on more errors (empty or invalid locations
    are still handled like in previous versions)
    o replace sprintfs() and strcpys() with snprintfs()
  * translation updates
    o new Portugal translation
  * device layer updates
    o make BlueZ connection non blocking on read()
- removed obsolete patch:
  * sms-out-of-sync.patch (included in update)
* Thu Nov  8 2007 prusnak@suse.cz
- fixed crashes when sending text message [#336961]
  (sms-out-of-sync.patch)
* Wed Oct 31 2007 prusnak@suse.cz
- added pcsc-lite-devel to BuildRequires
- don't package .la files
- cleaned spec file
* Tue Oct 30 2007 prusnak@suse.cz
- updated to 0.6.20
  * libgnokii updates
    o add support for Nokia 6070 and 2630
    o add a driver for PC/SC SIM card readers using libpcsclite;
    see Docs/README-PCSC for details
    o add two new phonebook memory types: SD for "Service Dialing
    Numbers" and BD for "Barred Dialing Numbers"
    o improve error messages while parsing config file
    o enhance error handling for parsing config
    o remove gn_file_text_save() from API
    o remove getline() replacement from compat.c
    o add gn_sms2mbox() function that converts SMS to mbox
    compliant format
    o add sanity checking for fwrite()/write() calls
    o make incoming buffer size for atbus link driver dynamically
    allocatable (was fixed size)
    o prevent strip_slashes() from stripping non-slashes
  * build system updates
    o add FAQ, KNOWN_BUGS and README-DKU2 to the list of files
    installed with "make install-docs" and remove
    gnokii-hackers-howto, gettext-howto and packaging-howto from
    that list
    o simplify Makefiles, remove obsolete targets
    o don't fail on parallel builds
    o fix compilation warnings
    o use standard paths for docdir and localedir
  * gnokii updates
    o add error handling for security commands
    o getprofile requires ringtone_list being allocated (Pawel Kot)
    o replace gn_file_text_save() with local writefile()
    o add getline() replacement to gnokii-utils.c
    o gnokii --getsms new --append-file/-a switch to append SMS
    to an existing file
    o gnokii --getsms -f/-F/-a use now mbox compliant format for
    stored sms, all sms read are stored in the same file
    o write more messages to stderr; the rule is that diagnostics
    indicating success or failure go to stderr, while information
    read from the phone goes to stdout
    o add sanity checking for fwrite()/write() calls
  * at driver updates
    o fix buffer size calculating in AT_WritePhonebook
    o fix SMS-SUBMIT parsing
    o calculate phonebook size for SonyEricsson: they don't answer
    with memory stats to AT+CPBS, calculate it by reading and
    counting entries (which is fast)
    o fix SetDateTime for Sony Ericsson, which requires timezone
    to be added
  * documentation updates
    o update Docs/protocol/nk6110.txt with another error code for
    "Get code status err"
  * nk6100 driver updates
    o add error code GN_ERR_SIMPROBLEM for --changesecuritycode
  * xgnokii updates
    o when exporting the phonebook to a file in raw format handle
    backslashes as escapes like in gnokii --getphonebook
  * link layer updates
    o make DKU-5 connection initialisation working again
  * translation updates
    o updated Italian translation and fixed Content-Type to match
    actual encoding of text which was UTF-8
* Tue Oct  9 2007 prusnak@suse.cz
- updated to 0.6.19
  * libgnokii updates
    o match declaration with definition
    o fix base64 encoding
    o read reference id from send sms reply and from delivery
    report
    o in gn_phonebook2ldif() output homePostalAddress when it isn't
    in a subentry
    o fix some typos
    o minor code cleanup in unixserial.c
    o some phones allow SMS location 0
  * build system updates
    o define u_int8_t where not present
    o include sys/time.h from gnokii.h
    o don't allow empty '-L' argument with Xlibs
  * gnokii updates
    o fix getallfiles
    o return non-zero error code when writephonebook fails
    o initialize networkinfo structure for --getnetworkinfo
  * xgnokii changes
    o try to avoid xgnokii freeze on exit for blacklisted phones;
    this is not a fix, just nasty workaround
  * nk6510 driver updates
    o fix segfault for sendsms
  * nk6100 driver updates
    o do not segfault when using --getsmsreader
  * atgen driver updates
    o Sony Ericsson phones can't do CREG=2 (only CREG=1), so just
    skip that and only do COPS in getnetworkinfo
* Thu Jul 26 2007 prusnak@suse.cz
- updated to 0.6.18
  * at driver updates
    o mark SMS messages as read/unread/sent/unsent where possible
    o fix battery level reading
    o add support for call notifications
    o add support for getActiveCalls
    o fix sms outbox reading
    o don't segfault if data->battery_unit is not allocated
    o add support for SMS notifications
    o fix in unsolicited messages handling
    o make SMS notifications more portable and move specific Nokia
    stuff to atnok.c
  * libgnokii updates
    o add void *callback_data argument to callbacks
    o use GN_CALL_MAX_PARALLEL instead of hardcode
    o add more sanity checks for sms reading
    o extend cell broadcast callback with gn_statemachine argument
    o fix splitting long messages
    o add support for occurrences field in calendar
    o add function for checking available connection types
    o fix memory leak in gn_sms_send() when sms_prepare() fails
    (found by valgrind) and pass on more return values from
    encode/decode functions
    o fix error message for "debug" option in gnokiirc: supported
    values have always been "off" and "on"
  * nk6510 driver updates
    o add support for incoming sms callbacks
    o add support for occurrences field in calendar
    o account for phonebook blocks not sent due to limited packet space
    o set of address blocks counts as one data block
    o treat Postal entries as addresses
    o when processing incoming phone book messages, skip unrelated
    errors
    o avoid duplicate phonebook subentries
    o speed up reading calendar entries
  * nokia_dku2 module updates
    o add N70 id and new endpoint addresses
  * nk6100 driver updates
    o add GN_OP_GetSMSFolders and GN_OP_GetSMSFolderStatus to
    support gnokii --showsmsfolderstatus
  * gnokii updates
    o update callback functions to match current libgnokii
    o add support for occurrences field in calendar
  * smsd updates
    o add support for multipart SMS for MySQL backend
* Fri Jun 22 2007 prusnak@suse.cz
- updated to 0.6.17 (see ChangeLog for all changes)
  * gnokii updates
    o do not open the log file when communication with phone is not
    needed; this fixes a memory leak found with valgrind
    o fix valgrind error "Conditional jump or move depends on
    uninitialised value(s)" in --getwapsetting
    o fix valgrind error "Conditional jump or move depends on
    uninitialised value(s)" in --getprofile
    o fix --divert options parsing
    o return an error if unexpected optional arguments are given to
    some commands and do stricter error checking
    o make --getphonebook output a telephone number in --ldif
    format even when there are no subentries
    o let foogle() access global data and state
    o fix command arguments handling for getting, setting and
    playing ringtones
  * libgnokii updates
    o fix memory leaks when config file has been open and memory
    allocated but [global] section or section given with --phone
    are not found (another valgrind finding)
    o in serial_close() fix valgrind warning "invalid file
    descriptor -1 in syscall close()" when serial_open() failed
    (eg. wrong permissions on /dev/ttyS0)
    o introduce use_locking field to config structure and fill it
    from the config file
    o make strings in cfgreader better translatable
    o use default values when incorrect option is given in the
    config file (where safe and possible)
    o for connection type dku2libusb treat port as the number of
    DKU2 USB endpoint; this is useful when you have more than
    one DKU2 phone connected to the computer; numbering goes
    from 1 upwards
    o in gn_file_phonebook_raw_parse() parse all the fields even if
    an empty name is given
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
  Remove unneded Requires libusb
* Wed May  9 2007 prusnak@suse.cz
- updated to 0.6.15 (see ChangeLog for all changes)
  * libgnokii changes
    o handle new type of phonebook number for ldif and vcard output
    o be more compliant with VCARD 3.0
    o add Nokia 6136 support
    o fix overflow when printing SMS date
    o add new phonebook entry types
    o for concatenated messages send the smallest part at the end
    o for concatenated unicode messages try not to split character
    across multiple parts
    o add support for Nokia 6233
    o fix segfault on contacts handling in AT driver for long names
    o improve INT_MAX detection
    o make gn_ical2calnote() and gn_ical2todo() print the parsed
    notes only when debug = on
    o don't invoke additional fcntls when with_async is set to 0,
    which is always
    o add extented phonebook support into public API
    o add file types into public API
    o add support for extented phonebook (not quite works yet)
  * gnokii updates
    o search for default config files if an empty filename is given
    to --config
    o fix --setdatetime segfault
    o fix --deletephonebook incorrect argument number counting
    o print phonebook entry number in case when there's no
    subentry
    o fix logo options segfaults
    o exit gnokii after --viewlogo or --listnetworks
    o compare network name with translated "unknown" string in logo
    operations too
    o make --getspeeddial and --setspeeddial print to stdout on
    success, not stderr
    o fix --getringtone parsing options
    o fix --sendsms usage string: -r is the short form of --report
    o use readtext() in savesms() too
- dropped obsolete patches:
  * cvs.patch (included in update)
  * fbusinit.patch (included in update)
  * maxlen.patch (included in update)
* Fri Feb 23 2007 prusnak@suse.cz
- backported code from CVS fixing buffer overflows (cvs.patch) [#237107]
- fixed 'array subscript out of range' (maxlen.patch)
* Wed Jan 24 2007 prusnak@suse.cz
- cleaned spec file and thus fixed build errors
* Wed Jan  3 2007 prusnak@suse.cz
- fixed uninitialised variable (fbusinit.patch) [#231178]
* Tue Dec  5 2006 prusnak@suse.cz
- moved xgnokii manpage from /usr/X11R6/man to %%{_mandir} [#225092]
* Mon Nov 13 2006 ro@suse.de
- really remove resmgr support
* Mon Nov 13 2006 mjancar@suse.cz
- disable resmgr patch (#218662)
* Mon Aug 28 2006 dgollub@suse.de
- update to 0.6.14
  * gnokii updates
  o added --config and --phone options
  o gnokii functions got splitted in several files
  o ...
  * libgnokii updates
  o added gn_wap_push functions
  o fixed encoding issue on 64bit systems
  o Nokia 6280 and 3220 support added
  o handle new types of telephone numbers
  o added functions to load config from alternate file
  o fixed serveral bugs
  o ...
  * utils updates
  o added 'waitcall' program which can be used in a script
  to get phone number of incoming call.
  o ...
  * nk6510 driver updates
  * nk6100 driver updates
  * documentation updates
  * translation updates
- removed wchar patch for 64bit systems
* Wed Aug 16 2006 ro@suse.de
- workaround missing makefile deps for parallel make
- call gettextize for mkinstalldirs problem
* Mon Jul 10 2006 dgollub@suse.de
- fixed encoding problem for 64bit systems (wrong wchar_t casting)
* Mon Jun 19 2006 dgollub@suse.de
- update to 0.6.13
  * libgnokii updates
    o added library layer
    o added GNOKII_API and GNOKII_DEPRECTAED
    o added support for caller groups
    o added encoding setup function for libgnokii
    o ...
  * nk6510 updates
    o added support for writing extended calendar information
    o Nokia 6680 support added
    o Nokia Series 40 support added
  * device layer updates
    o new libusb driver for dku2 cable (connection = dku2libusb)
  * gnokii, xgnokii, libgnokii bugfixes
- modified resmgr patch (added --enable-resmgr option)
- moved smsd manpages from -devel to -smsd package
- removed smsd libtool files
- moved pkgconfig and .la files to -devel package
- updated descriptions of -devel and -smsd package
- updated authors list
* Mon Jun 12 2006 poeml@suse.de
- update to 0.6.12
  * nk6510 driver updates
    o Nokia 6015i support added
    o Nokia 6101 support added
    o Nokia 6680 support added
    o Nokia 6235 over IrDA support
  * documentation updates
    o non Nokia phones are supported by AT driver -- express it
    more verbosively
  * atgen driver updates
    o identify should work on phones not supporting "AT+CGxx"
    commands
  * xgnokii, libgnokii, gnokiid bugfixes
- compile with libical instead of its own deprecated ical
  implementation
- compile with -fno-strict-aliasing
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 mjancar@suse.cz
- update to 0.6.10
- compile with -fstack-protector
* Sat Sep  3 2005 matz@suse.de
- Put -lresmgr in the right place, so that libgnokii.so is linked
  against it. [fixes kdepim3 build]
* Tue Aug 30 2005 mjancar@suse.cz
- add resmgr support (#62927)
- branch devel subpackage
* Wed Aug 10 2005 sbrabec@suse.cz
- Do not require -devel packages.
* Mon Aug  1 2005 mjancar@suse.cz
- update to 0.6.8
* Tue Apr 26 2005 meissner@suse.de
- fixed 1 byte buffer overflow in sms number handling.
* Thu Apr 14 2005 mjancar@suse.cz
- fix for gcc 4.0
* Fri Feb 25 2005 mjancar@suse.cz
- update to 0.6.4
* Wed Dec 15 2004 hvogel@suse.de
- fix desktop file
* Tue Jul 13 2004 adrian@suse.de
- drop ical support again.
  libical gets dropped and the functionality is present in kmobile
* Mon Jul  5 2004 adrian@suse.de
- update to version 0.6.3
- enable bluetooth support
- enable ical support
- enable security support
* Thu Apr  8 2004 mjancar@suse.cz
- fix permissions verifying (#38641)
* Fri Feb 27 2004 mjancar@suse.cz
- update to 0.6.0
* Tue Feb 17 2004 adrian@suse.de
- fix Categories
* Thu Oct 30 2003 mjancar@suse.cz
- fix permissions
- no root for build
* Thu Oct 16 2003 mjancar@suse.cz
- fix segfault on exit (#32233)
* Fri Oct 10 2003 mjancar@suse.cz
- update to 0.5.5
* Fri Aug 15 2003 adrian@suse.de
- install icon and desktop file
* Fri Jun 20 2003 mjancar@suse.cz
- fix locales instalation
- use %%{run_ldconfig}
* Tue Jun 17 2003 mjancar@suse.cz
- update to 0.5.2
- kill obsolete patches
* Tue May 27 2003 ro@suse.de
- added smssend and ppm2nokia to filelists
* Mon Feb 17 2003 vbobek@suse.cz
- updated to version 0.5.0pre6
  * source cleanup
  * API improved
  * new features
  * more mobiles working with the driver
  * doc updated
  * bug fixes
  * added subpackage smsd
- added patch for compiling with -fPIC
* Tue Jul 30 2002 uli@suse.de
- build with -fPIC (fixes x86-64)
* Tue Jul 23 2002 stark@suse.de
- update to 0.4.2
- fixed type in Makefile
* Mon Jul 15 2002 stark@suse.de
- update to 0.4.1
- use %%{_libdir} for shared lib
* Fri Jul 12 2002 stark@suse.de
- update to 0.4.0
* Thu Jul 11 2002 meissner@suse.de
- auto* rerun.
* Mon Apr 29 2002 stark@suse.de
- update to 0.3.5
  * This version corrects the datacall problem introduced in 0.3.4.
    This version is only released because there is no stable
    version from the next gnokii series (0.4).
* Tue Mar 19 2002 stark@suse.de
- security update to 0.3.4 (#14960)
- removed suid-bit from mgnokiidev (-> permissions.easy)
* Mon Oct  1 2001 stark@suse.de
- use BuildRoot
- update to 0.3.3
- gnokii group is no longer needed -> uucp
- splitted package into gnokii and xgnokii
* Mon Sep 24 2001 stark@suse.de
- cleanup spec-file a bit
* Sun Sep 23 2001 stark@suse.de
- removed init-script (gnokiid has to be started for every
  connection)
- removed rc.config variables
* Sun Sep 23 2001 stark@suse.de
- moved rc-link to /etc/init.d
* Thu Jan 25 2001 tw@suse.de
- added an init-script to start gnokiid
- install the configuration file.
